@@ -21,7 +21,9 @@ class AboutDialog : public QDialog
 
         void setText(const QString& text); //set about dialog text content
 
-        void setIcon(const QString& iconPath); //set about dialog icon
+        void setTopIcon(const QString& iconPath); //set about dialog top icon
+
+        void setBottomIcon(const QString& iconPath); //set about dialog bottom icon
 
     private:
 
@@ -31,6 +33,8 @@ class AboutDialog : public QDialog
 
         QLabel m_Icon; //dialog icon
 
+        QLabel m_BottomIcon; //additional icon (used to display Spotify Core logo)
+
         QPushButton m_DoneBtn; //Done button
 
     private slots:
